@@ -88,17 +88,22 @@ def get_stack_mixture_vars(
             join_axis = int(get_constant_value(join_axis))
         except ValueError:
             # TODO: Support symbolic join axes
-            return None
+            raise NotImplementedError(
+                "Symbolic `Join` axes are not supported in mixtures"
+            )
 
         if join_axis != 0:
             # TODO: Support other join axes
-            return None
+            raise NotImplementedError("Only `Join` axis 0 is supported in mixtures")
 
     if not all(
         rv.owner and isinstance(rv.owner.op, RandomVariable) for rv in mixture_rvs
     ):
         # Currently, all mixture components must be `RandomVariable` outputs
         # TODO: Allow constants and make them Dirac-deltas
+        # raise NotImplementedError(
+        #     "All mixture components must be `RandomVariable` outputs"
+        # )
         return None
 
     return mixture_rvs
@@ -132,7 +137,7 @@ def mixture_replace(fgraph, node):
 
     mixture_rvs = mixture_res
 
-    mixture_value_var = rv_map_feature.rv_values.pop(out_var, None)
+    mixture_value_var = rv_map_feature.rv_values[out_var]
 
     # We loop through mixture components and collect all the array elements
     # that belong to each one (by way of their indices).
@@ -146,7 +151,7 @@ def mixture_replace(fgraph, node):
 
     new_mixture_rv = new_node.default_output()
     new_mixture_rv.name = "mixture"
-    rv_map_feature.rv_values[new_mixture_rv] = mixture_value_var
+    rv_map_feature.update_rv_maps(out_var, mixture_value_var, new_mixture_rv)
 
     # FIXME: This is pretty hackish
     fgraph.import_node(new_node, import_missing=True, reason="mixture_rv")
